Index: include/core/SkCanvas.h |
diff --git a/include/core/SkCanvas.h b/include/core/SkCanvas.h |
index 2812b32856a082a9913882c276fe4a3d102a2c95..4ad915c641294e84f99c1ddad2b451de2967c888 100644 |
--- a/include/core/SkCanvas.h |
+++ b/include/core/SkCanvas.h |
@@ -1379,11 +1379,10 @@ private: |
SkBaseDevice* init(SkBaseDevice*, InitFlags); |
/** |
* Gets the size/origin of the top level layer in global canvas coordinates. We don't want this |
* to be public because it exposes decisions about layer sizes that are internal to the canvas. |
*/ |
- SkISize getTopLayerSize() const; |
- SkIPoint getTopLayerOrigin() const; |
+ SkIRect getTopLayerBounds() const; |
void internalDrawBitmapRect(const SkBitmap& bitmap, const SkRect* src, |
const SkRect& dst, const SkPaint* paint, |
@@ -1379,11 +1379,10 @@ private: |
SkBaseDevice* init(SkBaseDevice*, InitFlags); |
/** |
- * Gets the size/origin of the top level layer in global canvas coordinates. We don't want this |
+ * Gets the bounds of the top level layer in global canvas coordinates. We don't want this |
* to be public because it exposes decisions about layer sizes that are internal to the canvas. |
*/ |